//
//  SymbolicKeys.h
//  SystemKeys
//
//  Created by Dave Jewell on 06/02/2009.
//  Copyright 2009 Cocoa Secrets. All rights reserved.
//

#import <Cocoa/Cocoa.h>

// CGSSymbolicHotKey is adopted from work by Joe Ranieri, Alacatia Labs.

typedef enum		
{
	kCGSHotKeyFocusMenubar											= 7,
	kCGSHotKeyFocusDock													= 8,
	kCGSHotKeyFocusNextGlobalWindow							= 9,
	kCGSHotKeyFocusToolbar											= 10,
	kCGSHotKeyFocusFloatingWindow								= 11,
	kCGSHotKeyToggleFullKeyboardAccess					= 12,
	kCGSHotKeyFocusNextControl									= 13,
	
	kCGSHotKeyToggleZoom												= 15,
	kCGSHotKeyZoomIn														= 17,
	kCGSHotKeyZoomOut														= 19,
	
	kCGSHotKeyInvertScreen											= 21,
	kCGSHotKeyZoomToggleSmoothing								= 23,
	kCGSHotKeyIncreaseContrast									= 25,
	kCGSHotKeyDecreaseContrast									= 26,
	kCGSHotKeyFocusApplicationWindow						= 27,
	kCGSHotKeyScreenshot												= 28,
	kCGSHotKeyScreenshotToClipboard							= 29,
	kCGSHotKeyScreenshotRegion									= 30,								// Screenshots: Normally Cmd-Shift 4
	kCGSHotKeyScreenshotRegionToClipboard				= 31,								// Screenshots: Normally Cmd-Ctrl-Shift 4
	kCGSHotKeyExposeAllWindows									= 32,
	kCGSHotKeyExposeApplicationWindows					= 33,
	kCGSHotKeyExposeAllWindowsSlow							= 34,
	kCGSHotKeyExposeApplicationWindowsSlow			= 35,
	kCGSHotKeyExposeDesktop											= 36,
	kCGSHotKeyExposeDesktopsSlow								= 37,	
	
	kCGSHotKeyToggleCharacterPallette						= 50,
	kCGSHotKeyFocusDrawer												= 51,
	kCGSHotKeyToggleDockAutohide								= 52,
	kCGSHotKeyDecreaseDisplayBrightness					= 53,
	kCGSHotKeyIncreaseDisplayBrightness					= 54,
	kCGSHotKeyFocusStatusItems									= 57,
	kCGSHotKeyToggleVoiceOver										= 59,
	kCGSHotKeySelectPreviousInputSource					= 60,
	kCGSHotKeySelectNextInputSource							= 61,
	kCGSHotKeyDashboard													= 62,
	kCGSHotKeyDashboardSlow											= 63,
	kCGSHotKeySpotlightSearchField							= 64,
	kCGSHotKeySpotlightWindow										= 65,
	kCGSHotKeyLookUpWordInDictionary						= 70,								// Dictionary support: Normally Ctrl-Cmd-D
	kCGSHotKeyToggleFrontRow										= 73,
	
	// Stuff from hereon requires Leopard or better
	
	kCGSHotKeySpaces														= 75,
	kCGSHotKeySpacesSlow												= 76,
	kCGSHotKeySpaceLeft													= 79,
	kCGSHotKeySpaceLeftSlow											= 80,
	kCGSHotKeySpaceRight												= 81,
	kCGSHotKeySpaceRightSlow										= 82,
	kCGSHotKeySpaceDown													= 83,
	kCGSHotKeySpaceDownSlow											= 84,
	kCGSHotKeySpaceUp														= 85,
	kCGSHotKeySpaceUpSlow												= 86,
	
	kCGSHotKeyHelp															= 98
	
	// Leopard actually supports symbolic hotkey codes up to 149 
	// Presumably, anything after that is Snow Leopard....
		
} CGSSymbolicHotKey;

typedef struct 
{
	CGSSymbolicHotKey _symbolicKey;						// key for this representation
	NSUInteger _eventFlags;
	NSInteger _keyCode;
	NSUInteger _modifierFlags;
	NSInteger unknown [9];
} CGSHotKeyRepresentation;
	
extern NSInteger CGSMainConnectionID (void);
extern bool CGSIsSymbolicHotKeyEnabled (CGSSymbolicHotKey hotKey);
extern CGError CGSSetSymbolicHotKey (NSInteger cid, NSUInteger dataCode, CGSSymbolicHotKey hotKey);
extern CGError CGSSetSymbolicHotKeyEnabled (CGSSymbolicHotKey hotKey, bool enabled);
extern CGError CGSGetSymbolicHotKeyValue (CGSSymbolicHotKey hotkey, unsigned short * eventFlags, unsigned short * keyCode, NSUInteger * modifierFlags);
extern CGError CGSSetSymbolicHotKeyValue (CGSSymbolicHotKey hotkey, NSUInteger eventFlags, NSUInteger keyCode, NSUInteger modifierFlags);
extern CGError CGSGetSymbolicHotKeyRepresentation (CGSSymbolicHotKey hotkey, CGSHotKeyRepresentation * representation, NSInteger representationSize);
extern CGError CGSSetSymbolicHotKeyRepresentation (CGSSymbolicHotKey hotkey, CGSHotKeyRepresentation * representation, NSInteger representationSize);

